@@ -49,7 +49,7 @@ class RosTable(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosTableProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosTableProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -255,7 +255,7 @@ class RosTable(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosTable.SchemaProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosTable.SchemaProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -460,8 +460,8 @@ class RosTable(
             if __debug__:
                 def stub(
                     *,
-                    columns: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosTable.ColumnsProperty", typing.Dict[str, typing.Any]]]]],
-                    partitions: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosTable.PartitionsProperty", typing.Dict[str, typing.Any]]]]]] = None,
+                    columns: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosTable.ColumnsProperty, typing.Dict[str, typing.Any]]]]],
+                    partitions: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosTable.PartitionsProperty, typing.Dict[str, typing.Any]]]]]] = None,
                 ) -> None:
                     ...
                 type_hints = typing.get_type_hints(stub)
@@ -697,7 +697,7 @@ class Table(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["TableProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[TableProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
